"""
	0/1 Knapsack -- Dynamic programming
	O(n W) time, O(n W) space
"""
def knapsack(n, W, weight, value): 
	"""Solve a knapsack instance on n items with weights weight[1..n], values value[1..n] and knapsack capacity W
	Return (val, sol) where: 
	- val is the largest sum of value[i] for i in 1..n whose weights weight[i] sum to at most W
	- The indices of elements are stored in sol"""
	opt = [ [0]*(W+1) for i in range(0, n+1) ] #crea la tabella di programmazione dinamica
	for i in range(1, n+1): 
		for w in range(0, W+1): 
			if weight[i] > w:
				opt[i][w] = opt[i-1][w]
			else:
				opt[i][w] = max( opt[i-1][w], value[i] + opt[i-1][w - weight[i]] )
	val = opt[n][W]
	sol = [] # lista degli oggetti inclusi nella bisaccia
	i, w = n, W
	while i > 0: 
		if opt[i][w] > opt[i-1][w]: 
			sol.append(i) # aggiungo l'oggetto i alla soluzione
			w = w - weight[i]
		i = i-1
	return val, sol[::-1]

def main(): 
	n, W = [ int(s) for s in input().split() ] # es. [4, 11]
	value = (n+1) * [0]
	weight = (n+1) * [0]
	for i in range(1, n+1): # i è l'indice di un oggetto
		value[i], weight[i] = [int(s) for s in input().split()] # es. [8, 4]
	
	# eseguo l'algoritmo:
	val, sol = knapsack(n, W, weight, value)
	print(val)
	for i in sol: 
		print(i, end=' ')
	print()

if __name__ == "__main__": main()

